@@ -115,17 +115,20 @@ class Parser:
         Заполняет структуру дерева разделов, выраженную уровнями вложенности разделов.
         """
         for heading, text in headings_with_texts.items():
+            max_ratio = 0
+            text_parent = None
+
             query_doc = [word for word in simple_preprocess(heading, min_len=1, max_len=50)]
             query_doc_bow = self.dictionary.doc2bow(query_doc)
             query_doc_tf_idf = self.tf_idf[query_doc_bow]
 
-            max_idx = 0
-            for i in range(1, len(self.similarity[query_doc_tf_idf])):
-                if self.similarity[query_doc_tf_idf][i] > self.similarity[query_doc_tf_idf][max_idx]:
-                    max_idx = i
+            for i in range(len(self.similarity[query_doc_tf_idf])):
+                if self.similarity[query_doc_tf_idf][i] > max_ratio:
+                    max_ratio = self.similarity[query_doc_tf_idf][i]
+                    text_parent = self.sections_tree.get_leaf_sections()[i]
 
-            text_parent = self.sections_tree.get_leaf_sections()[max_idx]
-            text_parent.text = text
+            if text_parent is not None:
+                text_parent.text = text
 
     def iter_paragraphs(self, parent):
         if isinstance(parent, DocumentWithTable):
@@ -154,7 +157,8 @@ class Parser:
         query_doc = [word for word in simple_preprocess(p_text, min_len=1, max_len=50)]
         query_doc_bow = self.dictionary.doc2bow(query_doc)
         query_doc_tf_idf = self.tf_idf[query_doc_bow]
-        return max(self.similarity[query_doc_tf_idf]) >= configs.MIN_SIMILARITY_RATIO
+        text_similarity_ratio = max(self.similarity[query_doc_tf_idf])
+        return text_similarity_ratio >= configs.MIN_SIMILARITY_RATIO
 
     @staticmethod
     def is_table_element(paragraph: Paragraph, doc: Document) -> bool:
